
#Multiple linear regression and random forest models for prediction of salt concentrations in Antarctic soils
#The training datasets are published by Diaz et al. (2020), see below. 
#Please cite [Diaz, M. A., Gardner, C. B., Welch, S. A., Andrew Jackson, W., Wall, D. H., 
#Hogg, I. D., Fierer, N. and Berry Lyons, W.: Geochemical zones and environmental gradients for 
#soils from the Central Transantarctic Mountains, Antarctica, Biogeosciences Discuss., 1-29, 
#doi:10.5194/bg-2020-316, 2020] for use of the datasets and models.

#Loading all required packages
library(readxl)
library(ggplot2)
library(randomForest)
library(e1071)
library(caret)
library(smatr)


#Import the training datasets for the multiple linear regression and random forest models
Salts <- read_excel("~/Downloads/Salts.xlsx")
RFSalts_Train <- read_excel("~/Downloads/RFSalts_Train.xlsx")
RFSalts_Test <-read_excel("~/Downloads/RFSalts_Test.xlsx")
Darwin <- read_excel("~/Downloads/Darwin_Test.xlsx")

###########################################################################################################################
#Creating the multiple linear regression models using the Salts dataset

#For Total salts
#Creating the linear model with the 5 geographic parameters + soil moisture
TSreg <- lm(data = Salts, log(Total_salt)~ Latitude + Longitude + Elevation + Distance_from_coast + 
              Distance_from_glacier + Soil_moisture, na.action = na.omit)
#Printing model statistics to evaluate model strength
summary(TSreg)

#For N:P ratio
NPreg <- lm(data = Salts, log(NP)~ Latitude + Longitude + Elevation + Distance_from_coast + 
              Distance_from_glacier + Soil_moisture)
summary(NPreg)

#For ClO4
ClO4reg <- lm(data = Salts, log(ClO4)~ Latitude + Longitude + Elevation + Distance_from_coast + 
                Distance_from_glacier + Soil_moisture, na.action = na.omit)
summary(ClO4reg)

#For ClO3
ClO3reg <- lm(data = Salts, log(ClO3)~ Latitude + Longitude + Elevation + Distance_from_coast + 
                Distance_from_glacier + Soil_moisture, na.action = na.omit)
summary(ClO3reg)

#For Cl
Clreg <- lm(data = Salts, log(Cl)~ Latitude + Longitude + Elevation + Distance_from_coast + 
              Distance_from_glacier + Soil_moisture, na.action = na.omit)
summary(Clreg)

#For F
Freg <- lm(data = Salts, log(F)~ Latitude + Longitude + Elevation + Distance_from_coast + 
             Distance_from_glacier + Soil_moisture, na.action = na.omit)
summary(Freg)

#For NO3
NO3reg <- lm(data = Salts, log(NO3)~ Latitude + Longitude + Elevation + Distance_from_coast + 
               Distance_from_glacier + Soil_moisture, na.action = na.omit)
summary(NO3reg)

#For SO4
SO4reg <- lm(data = Salts, log(SO4)~ Latitude + Longitude + Elevation + Distance_from_coast + 
               Distance_from_glacier + Soil_moisture, na.action = na.omit)
summary(SO4reg)

#For PO4
PO4reg <- lm(data = Salts, log(PO4)~ Latitude + Longitude + Elevation + Distance_from_coast + 
               Distance_from_glacier + Soil_moisture, na.action = na.omit)
summary(PO4reg)

#For Ca
Careg <- lm(data = Salts, log(Ca)~ Latitude + Longitude + Elevation + Distance_from_coast + 
              Distance_from_glacier + Soil_moisture, na.action = na.omit)
summary(Careg)

#For Mg
Mgreg <- lm(data = Salts, log(Mg)~ Latitude + Longitude + Elevation + Distance_from_coast + 
              Distance_from_glacier + Soil_moisture, na.action = na.omit)
summary(Mgreg)

#For Na
Nareg <- lm(data = Salts, log(Na)~ Latitude + Longitude + Elevation + Distance_from_coast + 
              Distance_from_glacier + Soil_moisture, na.action = na.omit)
summary(Nareg)

#For K
Kreg <- lm(data = Salts, log(K)~ Latitude + Longitude + Elevation + Distance_from_coast + 
             Distance_from_glacier + Soil_moisture, na.action = na.omit)
summary(Kreg)

#For Sr
Srreg <- lm(data = Salts, log(Sr)~ Latitude + Longitude + Elevation + Distance_from_coast + 
              Distance_from_glacier + Soil_moisture, na.action = na.omit)
summary(Srreg)

#For NH3
NH3reg <- lm(data = Salts, log(NH3)~ Latitude + Longitude + Elevation + Distance_from_coast + 
               Distance_from_glacier + Soil_moisture, na.action = na.omit)
summary(NH3reg)

###########################################################################################################################

#Creating the random forest model with the training dataset
#mtry is set as default, which in this case is n/3 = 2. This is the value with the minimum error

#For Total salts
#Building the random forest model
RFModelTS <- randomForest(log(Total_salt) ~ Latitude + Longitude + Elevation + Distance_from_coast + Distance_from_glacier +
                            Soil_moisture, data = RFSalts_Train, na.action = na.omit, ntree = 2000)
#Seeing which variables were most and least important for nude purity
varImpPlot(RFModelTS)

#For N:P molar ratio
RFModelNP <- randomForest(log(NP) ~ Latitude + Longitude + Elevation + Distance_from_coast + Distance_from_glacier +
                            Soil_moisture, data = RFSalts_Train, na.action = na.omit, ntree = 2000)
varImpPlot(RFModelNP)

#For ClO4 
RFModelClO4 <- randomForest(log(ClO4) ~ Latitude + Longitude + Elevation + Distance_from_coast + Distance_from_glacier +
                              Soil_moisture, data = RFSalts_Train, na.action = na.omit, ntree = 2000)
varImpPlot(RFModelClO4)

#For ClO3 
RFModelClO3 <- randomForest(log(ClO3) ~ Latitude + Longitude + Elevation + Distance_from_coast + Distance_from_glacier +
                              Soil_moisture, data = RFSalts_Train, na.action = na.omit, ntree = 2000)
varImpPlot(RFModelClO3)

#For Cl
RFModelCl <- randomForest(log(Cl) ~ Latitude + Longitude + Elevation + Distance_from_coast + Distance_from_glacier +
                            Soil_moisture, data = RFSalts_Train, na.action = na.omit, ntree = 2000)
varImpPlot(RFModelCl)

#For F 
RFModelF <- randomForest(log(F) ~ Latitude + Longitude + Elevation + Distance_from_coast + Distance_from_glacier +
                           Soil_moisture, data = RFSalts_Train, na.action = na.omit, ntree = 2000)
varImpPlot(RFModelF)

#For NO3 
RFModelNO3 <- randomForest(log(NO3) ~ Latitude + Longitude + Elevation + Distance_from_coast + Distance_from_glacier +
                             Soil_moisture, data = RFSalts_Train, na.action = na.omit, ntree = 2000)
varImpPlot(RFModelNO3)

#For SO4 
RFModelSO4 <- randomForest(log(SO4) ~ Latitude + Longitude + Elevation + Distance_from_coast + Distance_from_glacier +
                             Soil_moisture, data = RFSalts_Train, na.action = na.omit, ntree = 2000)
varImpPlot(RFModelSO4)

#For PO4 
RFModelPO4 <- randomForest(log(PO4) ~ Latitude + Longitude + Elevation + Distance_from_coast + Distance_from_glacier +
                             Soil_moisture, data = RFSalts_Train, na.action = na.omit, ntree = 2000)
varImpPlot(RFModelPO4)

#For Ca 
RFModelCa <- randomForest(log(Ca) ~ Latitude + Longitude + Elevation + Distance_from_coast + Distance_from_glacier +
                            Soil_moisture, data = RFSalts_Train, na.action = na.omit, ntree = 2000)
varImpPlot(RFModelCa)

#For Mg 
RFModelMg <- randomForest(log(Mg) ~ Latitude + Longitude + Elevation + Distance_from_coast + Distance_from_glacier +
                            Soil_moisture, data = RFSalts_Train, na.action = na.omit, ntree = 2000)
varImpPlot(RFModelMg)

#For Na 
RFModelNa <- randomForest(log(Na) ~ Latitude + Longitude + Elevation + Distance_from_coast + Distance_from_glacier +
                            Soil_moisture, data = RFSalts_Train, na.action = na.omit, ntree = 2000)
varImpPlot(RFModelNa)

#For K 
RFModelK <- randomForest(log(K) ~ Latitude + Longitude + Elevation + Distance_from_coast + Distance_from_glacier +
                           Soil_moisture, data = RFSalts_Train, na.action = na.omit, ntree = 2000)
varImpPlot(RFModelK)

#For Sr 
RFModelSr <- randomForest(log(Sr) ~ Latitude + Longitude + Elevation + Distance_from_coast + Distance_from_glacier +
                            Soil_moisture, data = RFSalts_Train, na.action = na.omit, ntree = 2000)
varImpPlot(RFModelSr)

#For NH3 
RFModelNH3 <- randomForest(log(NH3) ~ Latitude + Longitude + Elevation + Distance_from_coast + Distance_from_glacier +
                             Soil_moisture, data = RFSalts_Train, na.action = na.omit, ntree = 2000)
varImpPlot(RFModelNH3)
###########################################################################################################################

#Running the Shackleton Glacier region test dataset on the generated multiple linear regression models

#For Total salts
#Inputting the new test dataset and storing the predicted concentration results
TSLMPred <- predict(TSreg, newdata = RFSalts_Test)
#Running a correlation between the measured and predicted values
cor.test(TSLMPred, log(RFSalts_Test$Total_salt))
#Quick visual check of the data
plot(TSLMPred, log(RFSalts_Test$Total_salt))
#Determining the slope by fitting bivariate lines using the standardized major axis (SMA) for measured and predicted values
#A slope of 1 is ideal, where there is a direct 1:1 relationship
#sma will test the slope estimate and determine the test statistic for the null hypothesis
sma(TSLMPred~ log(RFSalts_Test$Total_salt), slope.test=1)
#Determing the mean absolute error (MAE) and root mean squared error (RMSE)
MAE(TSLMPred, log(RFSalts_Test$Total_salt), na.rm = TRUE)
RMSE(TSLMPred, log(RFSalts_Test$Total_salt), na.rm = TRUE)

#For N:P ratio
NPLMPred <- predict(NPreg, newdata = RFSalts_Test)
cor.test(NPLMPred, log(RFSalts_Test$NP))
plot(NPLMPred, log(RFSalts_Test$NP))
sma(NPLMPred~ log(RFSalts_Test$NP), slope.test=1)
MAE(NPLMPred, log(RFSalts_Test$NP), na.rm = TRUE)
RMSE(NPLMPred, log(RFSalts_Test$NP), na.rm = TRUE)

#For ClO4
ClO4LMPred <- predict(ClO4reg, newdata = RFSalts_Test)
cor.test(ClO4LMPred, log(RFSalts_Test$ClO4))
plot(ClO4LMPred, log(RFSalts_Test$ClO4))
sma(ClO4LMPred~ log(RFSalts_Test$ClO4), slope.test=1)
MAE(ClO4LMPred, log(RFSalts_Test$ClO4), na.rm = TRUE)
RMSE(ClO4LMPred, log(RFSalts_Test$ClO4), na.rm = TRUE)

#For ClO3
ClO3LMPred <- predict(ClO3reg, newdata = RFSalts_Test)
cor.test(ClO3LMPred, log(RFSalts_Test$ClO3))
plot(ClO3LMPred, log(RFSalts_Test$ClO3))
sma(ClO3LMPred~ log(RFSalts_Test$ClO3), slope.test=1)
MAE(ClO3LMPred, log(RFSalts_Test$ClO3), na.rm = TRUE)
RMSE(ClO3LMPred, log(RFSalts_Test$ClO3), na.rm = TRUE)

#For Cl
ClLMPred <- predict(Clreg, newdata = RFSalts_Test)
cor.test(ClLMPred, log(RFSalts_Test$Cl))
plot(ClLMPred, log(RFSalts_Test$Cl))
sma(ClLMPred~ log(RFSalts_Test$Cl), slope.test=1)
MAE(ClLMPred, log(RFSalts_Test$Cl), na.rm = TRUE)
RMSE(ClLMPred, log(RFSalts_Test$Cl), na.rm = TRUE)

#For F
FLMPred <- predict(Freg, newdata = RFSalts_Test)
cor.test(FLMPred, log(RFSalts_Test$F))
plot(FLMPred, log(RFSalts_Test$F))
sma(FLMPred~ log(RFSalts_Test$F), slope.test=1)
MAE(FLMPred, log(RFSalts_Test$F), na.rm = TRUE)
RMSE(FLMPred, log(RFSalts_Test$F), na.rm = TRUE)

#For NO3
NO3LMPred <- predict(NO3reg, newdata = RFSalts_Test)
cor.test(NO3LMPred, log(RFSalts_Test$NO3))
plot(NO3LMPred, log(RFSalts_Test$NO3))
sma(NO3LMPred~ log(RFSalts_Test$NO3), slope.test=1)
MAE(NO3LMPred, log(RFSalts_Test$NO3), na.rm = TRUE)
RMSE(NO3LMPred, log(RFSalts_Test$NO3), na.rm = TRUE)

#For SO4
SO4LMPred <- predict(SO4reg, newdata = RFSalts_Test)
cor.test(SO4LMPred, log(RFSalts_Test$SO4))
plot(SO4LMPred, log(RFSalts_Test$SO4))
sma(SO4LMPred~ log(RFSalts_Test$SO4), slope.test=1)
MAE(SO4LMPred, log(RFSalts_Test$SO4), na.rm = TRUE)
RMSE(SO4LMPred, log(RFSalts_Test$SO4), na.rm = TRUE)

#For PO4
PO4LMPred <- predict(PO4reg, newdata = RFSalts_Test)
cor.test(PO4LMPred, log(RFSalts_Test$PO4))
plot(PO4LMPred, log(RFSalts_Test$PO4))
sma(PO4LMPred~ log(RFSalts_Test$PO4), slope.test=1)
MAE(PO4LMPred, log(RFSalts_Test$PO4), na.rm = TRUE)
RMSE(PO4LMPred, log(RFSalts_Test$PO4), na.rm = TRUE)

#For Ca
CaLMPred <- predict(Careg, newdata = RFSalts_Test)
cor.test(CaLMPred, log(RFSalts_Test$Ca))
plot(CaLMPred, log(RFSalts_Test$Ca))
sma(CaLMPred~ log(RFSalts_Test$Ca), slope.test=1)
MAE(CaLMPred, log(RFSalts_Test$Ca), na.rm = TRUE)
RMSE(CaLMPred, log(RFSalts_Test$Ca), na.rm = TRUE)

#For Mg
MgLMPred <- predict(Mgreg, newdata = RFSalts_Test)
cor.test(MgLMPred, log(RFSalts_Test$Mg))
plot(MgLMPred, log(RFSalts_Test$Mg))
sma(MgLMPred~ log(RFSalts_Test$Mg), slope.test=1)
MAE(MgLMPred, log(RFSalts_Test$Mg), na.rm = TRUE)
RMSE(MgLMPred, log(RFSalts_Test$Mg), na.rm = TRUE)

#For Na
NaLMPred <- predict(Nareg, newdata = RFSalts_Test)
cor.test(NaLMPred, log(RFSalts_Test$Na))
plot(NaLMPred, log(RFSalts_Test$Na))
sma(NaLMPred~ log(RFSalts_Test$Na), slope.test=1)
MAE(NaLMPred, log(RFSalts_Test$Na), na.rm = TRUE)
RMSE(NaLMPred, log(RFSalts_Test$Na), na.rm = TRUE)

#For K
KLMPred <- predict(Kreg, newdata = RFSalts_Test)
cor.test(KLMPred, log(RFSalts_Test$K))
plot(KLMPred, log(RFSalts_Test$K))
sma(KLMPred~ log(RFSalts_Test$K), slope.test=1)
MAE(KLMPred, log(RFSalts_Test$K), na.rm = TRUE)
RMSE(KLMPred, log(RFSalts_Test$K), na.rm = TRUE)

#For Sr
SrLMPred <- predict(Srreg, newdata = RFSalts_Test)
cor.test(SrLMPred, log(RFSalts_Test$Sr))
plot(SrLMPred, log(RFSalts_Test$Sr))
sma(SrLMPred~ log(RFSalts_Test$Sr), slope.test=1)
MAE(SrLMPred, log(RFSalts_Test$Sr), na.rm = TRUE)
RMSE(SrLMPred, log(RFSalts_Test$Sr), na.rm = TRUE)

#For NH3
NH3LMPred <- predict(NH3reg, newdata = RFSalts_Test)
cor.test(NH3LMPred, log(RFSalts_Test$NH3))
plot(NH3LMPred, log(RFSalts_Test$NH3))
sma(NH3LMPred~ log(RFSalts_Test$NH3), slope.test=1)
MAE(NH3LMPred, log(RFSalts_Test$NH3), na.rm = TRUE)
RMSE(NH3LMPred, log(RFSalts_Test$NH3), na.rm = TRUE)

###########################################################################################################################

#Running the Shackleton Glacier region test dataset on the generated random forest models

#For Total salts
#Inputting the new test dataset and storing the predicted concentration results
TSRFPred<- predict(RFModelTS, newdata = RFSalts_Test)
#Running a correlation between the measured and predicted values
cor.test(TSRFPred, log(RFSalts_Test$Total_salt))
#Quick visual check of the data
plot(TSRFPred, log(RFSalts_Test$Total_salt))
#Determining the slope by fitting bivariate lines using the standardized major axis (SMA) for measured and predicted values
#A slope of 1 is ideal, where there is a direct 1:1 relationship
#sma will test the slope estimate and determine the test statistic for the null hypothesis
sma(TSRFPred ~ log(RFSalts_Test$Total_salt), slope.test=1)
#Determing the mean absolute error (MAE) and root mean squared error (RMSE)
MAE(TSRFPred, log(RFSalts_Test$Total_salt), na.rm = TRUE)
RMSE(TSRFPred, log(RFSalts_Test$Total_salt), na.rm = TRUE)

#For N:P ratio
NPRFPred<- predict(RFModelNP, newdata = RFSalts_Test)
cor.test(NPRFPred, log(RFSalts_Test$NP))
plot(NPRFPred, log(RFSalts_Test$NP))
sma(NPRFPred ~ log(RFSalts_Test$NP), slope.test=1)
MAE(NPRFPred, log(RFSalts_Test$NP), na.rm = TRUE)
RMSE(NPRFPred, log(RFSalts_Test$NP), na.rm = TRUE)

#For ClO4
ClO4RFPred<- predict(RFModelClO4, newdata = RFSalts_Test)
cor.test(ClO4RFPred, log(RFSalts_Test$ClO4))
plot(ClO4RFPred, log(RFSalts_Test$ClO4))
sma(ClO4RFPred ~ log(RFSalts_Test$ClO4), slope.test=1)
MAE(ClO4RFPred, log(RFSalts_Test$ClO4), na.rm = TRUE)
RMSE(ClO4RFPred, log(RFSalts_Test$ClO4), na.rm = TRUE)

#For ClO3
ClO3RFPred<- predict(RFModelClO3, newdata = RFSalts_Test)
cor.test(ClO3RFPred, log(RFSalts_Test$ClO3))
plot(ClO3RFPred, log(RFSalts_Test$ClO3))
sma(ClO3RFPred ~ log(RFSalts_Test$ClO3), slope.test=1)
MAE(ClO3RFPred, log(RFSalts_Test$ClO3), na.rm = TRUE)
RMSE(ClO3RFPred, log(RFSalts_Test$ClO3), na.rm = TRUE)

#For Cl
ClRFPred<- predict(RFModelCl, newdata = RFSalts_Test)
cor.test(ClRFPred, log(RFSalts_Test$Cl))
plot(ClRFPred, log(RFSalts_Test$Cl))
sma(ClRFPred ~ log(RFSalts_Test$Cl), slope.test=1)
MAE(ClRFPred, log(RFSalts_Test$Cl), na.rm = TRUE)
RMSE(ClRFPred, log(RFSalts_Test$Cl), na.rm = TRUE)

#For F
FRFPred<- predict(RFModelF, newdata = RFSalts_Test)
cor.test(FRFPred, log(RFSalts_Test$F))
plot(FRFPred, log(RFSalts_Test$F))
sma(FRFPred ~ log(RFSalts_Test$F), slope.test=1)
MAE(FRFPred, log(RFSalts_Test$F), na.rm = TRUE)
RMSE(FRFPred, log(RFSalts_Test$F), na.rm = TRUE)

#For NO3
NO3RFPred<- predict(RFModelNO3, newdata = RFSalts_Test)
cor.test(NO3RFPred, log(RFSalts_Test$NO3))
plot(NO3RFPred, log(RFSalts_Test$NO3))
sma(NO3RFPred ~ log(RFSalts_Test$NO3), slope.test=1)
MAE(NO3RFPred, log(RFSalts_Test$NO3), na.rm = TRUE)
RMSE(NO3RFPred, log(RFSalts_Test$NO3), na.rm = TRUE)

#For SO4
SO4RFPred<- predict(RFModelSO4, newdata = RFSalts_Test)
cor.test(SO4RFPred, log(RFSalts_Test$SO4))
plot(SO4RFPred, log(RFSalts_Test$SO4))
sma(SO4RFPred ~ log(RFSalts_Test$SO4), slope.test=1)
MAE(SO4RFPred, log(RFSalts_Test$SO4), na.rm = TRUE)
RMSE(SO4RFPred, log(RFSalts_Test$SO4), na.rm = TRUE)

#For PO4
PO4RFPred<- predict(RFModelPO4, newdata = RFSalts_Test)
cor.test(PO4RFPred, log(RFSalts_Test$PO4))
plot(PO4RFPred, log(RFSalts_Test$PO4))
sma(PO4RFPred ~ log(RFSalts_Test$PO4), slope.test=1)
MAE(PO4RFPred, log(RFSalts_Test$PO4), na.rm = TRUE)
RMSE(PO4RFPred, log(RFSalts_Test$PO4), na.rm = TRUE)

#For Ca
CaRFPred<- predict(RFModelCa, newdata = RFSalts_Test)
cor.test(CaRFPred, log(RFSalts_Test$Ca))
plot(CaRFPred, log(RFSalts_Test$Ca))
sma(CaRFPred ~ log(RFSalts_Test$Ca), slope.test=1)
MAE(CaRFPred, log(RFSalts_Test$Ca), na.rm = TRUE)
RMSE(CaRFPred, log(RFSalts_Test$Ca), na.rm = TRUE)

#For Mg
MgRFPred<- predict(RFModelMg, newdata = RFSalts_Test)
cor.test(MgRFPred, log(RFSalts_Test$Mg))
plot(MgRFPred, log(RFSalts_Test$Mg))
sma(MgRFPred ~ log(RFSalts_Test$Mg), slope.test=1)
MAE(MgRFPred, log(RFSalts_Test$Mg), na.rm = TRUE)
RMSE(MgRFPred, log(RFSalts_Test$Mg), na.rm = TRUE)

#For Na
NaRFPred<- predict(RFModelNa, newdata = RFSalts_Test)
cor.test(NaRFPred, log(RFSalts_Test$Na))
plot(NaRFPred, log(RFSalts_Test$Na))
sma(NaRFPred ~ log(RFSalts_Test$Na), slope.test=1)
MAE(NaRFPred, log(RFSalts_Test$Na), na.rm = TRUE)
RMSE(NaRFPred, log(RFSalts_Test$Na), na.rm = TRUE)

#For K
KRFPred<- predict(RFModelK, newdata = RFSalts_Test)
cor.test(KRFPred, log(RFSalts_Test$K))
plot(KRFPred, log(RFSalts_Test$K))
sma(KRFPred ~ log(RFSalts_Test$K), slope.test=1)
MAE(KRFPred, log(RFSalts_Test$K), na.rm = TRUE)
RMSE(KRFPred, log(RFSalts_Test$K), na.rm = TRUE)

#For Sr
SrRFPred<- predict(RFModelSr, newdata = RFSalts_Test)
cor.test(SrRFPred, log(RFSalts_Test$Sr))
plot(SrRFPred, log(RFSalts_Test$Sr))
sma(SrRFPred ~ log(RFSalts_Test$Sr), slope.test=1)
MAE(SrRFPred, log(RFSalts_Test$Sr), na.rm = TRUE)
RMSE(SrRFPred, log(RFSalts_Test$Sr), na.rm = TRUE)

#For NH3
NH3RFPred<- predict(RFModelNH3, newdata = RFSalts_Test)
cor.test(NH3RFPred, log(RFSalts_Test$NH3))
plot(NH3RFPred, log(RFSalts_Test$NH3))
sma(NH3RFPred ~ log(RFSalts_Test$NH3), slope.test=1)
MAE(NH3RFPred, log(RFSalts_Test$NH3), na.rm = TRUE)
RMSE(NH3RFPred, log(RFSalts_Test$NH3), na.rm = TRUE)

###########################################################################################################################

#Running the Darwin Glacier region test dataset on the generated multiple linear regression models

#For Total salts
#Inputting the new test dataset and storing the predicted concentration results
Darwin_TSLMPred<-predict(TSreg, newdata = Darwin)
#Running a correlation between the measured and predicted values
cor.test(Darwin_TSLMPred, log(Darwin$Total_salt))
#Quick visual check of the data
plot(Darwin_TSLMPred, log(Darwin$Total_salt))
#Determining the slope by fitting bivariate lines using the standardized major axis (SMA) for measured and predicted values
#A slope of 1 is ideal, where there is a direct 1:1 relationship
#sma will test the slope estimate and determine the test statistic for the null hypothesis
sma(Darwin_TSLMPred~ log(Darwin$Total_salt), slope.test=1)
#Determing the mean absolute error (MAE) and root mean squared error (RMSE)
MAE(Darwin_TSLMPred, log(Darwin$Total_salt), na.rm = TRUE)
RMSE(Darwin_TSLMPred, log(Darwin$Total_salt), na.rm = TRUE)

#For N:P ratio
Darwin_NPLMPred <- predict(NPreg, newdata = Darwin)
cor.test(Darwin_NPLMPred, log(Darwin$NP))
plot(Darwin_NPLMPred, log(Darwin$NP))
sma(Darwin_NPLMPred~ log(Darwin$NP), slope.test=1)
MAE(Darwin_NPLMPred, log(Darwin$NP), na.rm = TRUE)
RMSE(Darwin_NPLMPred, log(Darwin$NP), na.rm = TRUE)

#For Cl
Darwin_ClLMPred <- predict(Clreg, newdata = Darwin)
cor.test(Darwin_ClLMPred, log(Darwin$Cl))
plot(Darwin_ClLMPred, log(Darwin$Cl))
sma(Darwin_ClLMPred~ log(Darwin$Cl), slope.test=1)
MAE(Darwin_ClLMPred, log(Darwin$Cl), na.rm = TRUE)
RMSE(Darwin_ClLMPred, log(Darwin$Cl), na.rm = TRUE)

#For NO3
Darwin_NO3LMPred <- predict(NO3reg, newdata = Darwin)
cor.test(Darwin_NO3LMPred, log(Darwin$NO3))
plot(Darwin_NO3LMPred, log(Darwin$NO3))
sma(Darwin_NO3LMPred~ log(Darwin$NO3), slope.test=1)
MAE(Darwin_NO3LMPred, log(Darwin$NO3), na.rm = TRUE)
RMSE(Darwin_NO3LMPred, log(Darwin$NO3), na.rm = TRUE)

#For Ca
Darwin_CaLMPred <- predict(Careg, newdata = Darwin)
cor.test(Darwin_CaLMPred, log(Darwin$Ca))
plot(Darwin_CaLMPred, log(Darwin$Ca))
sma(Darwin_CaLMPred~ log(Darwin$Ca), slope.test=1)
MAE(Darwin_CaLMPred, log(Darwin$Ca), na.rm = TRUE)
RMSE(Darwin_CaLMPred, log(Darwin$Ca), na.rm = TRUE)

#For Mg
Darwin_MgLMPred <- predict(Mgreg, newdata = Darwin)
cor.test(Darwin_MgLMPred, log(Darwin$Mg))
plot(Darwin_MgLMPred, log(Darwin$Mg))
sma(Darwin_MgLMPred~ log(Darwin$Mg), slope.test=1)
MAE(Darwin_MgLMPred, log(Darwin$Mg), na.rm = TRUE)
RMSE(Darwin_MgLMPred, log(Darwin$Mg), na.rm = TRUE)

#For Na
Darwin_NaLMPred <- predict(Nareg, newdata = Darwin)
cor.test(Darwin_NaLMPred, log(Darwin$Na))
plot(Darwin_NaLMPred, log(Darwin$Na))
sma(Darwin_NaLMPred~ log(Darwin$Na), slope.test=1)
MAE(Darwin_NaLMPred, log(Darwin$Na), na.rm = TRUE)
RMSE(Darwin_NaLMPred, log(Darwin$Na), na.rm = TRUE)

#For K
Darwin_KLMPred <- predict(Kreg, newdata = Darwin)
cor.test(Darwin_KLMPred, log(Darwin$K))
plot(Darwin_KLMPred, log(Darwin$K))
sma(Darwin_KLMPred~ log(Darwin$K), slope.test=1)
MAE(Darwin_KLMPred, log(Darwin$K), na.rm = TRUE)
RMSE(Darwin_KLMPred, log(Darwin$K), na.rm = TRUE)

###########################################################################################################################

#Running the Darwin Glacier region test dataset on the generated random forest models

#For Total salts
#Inputting the new test dataset and storing the predicted concentration results
Darwin_TSRFPred<-predict(RFModelTS, newdata = Darwin)
#Running a correlation between the measured and predicted values
cor.test(Darwin_TSRFPred, log(Darwin$Total_salt))
#Quick visual check of the data
plot(Darwin_TSRFPred, log(Darwin$Total_salt))
#Determining the slope by fitting bivariate lines using the standardized major axis (SMA) for measured and predicted values
#A slope of 1 is ideal, where there is a direct 1:1 relationship
#sma will test the slope estimate and determine the test statistic for the null hypothesis
sma(Darwin_TSRFPred~ log(Darwin$Total_salt), slope.test=1)
#Determing the mean absolute error (MAE) and root mean squared error (RMSE)
MAE(Darwin_TSRFPred, log(Darwin$Total_salt), na.rm = TRUE)
RMSE(Darwin_TSRFPred, log(Darwin$Total_salt), na.rm = TRUE)

#For N:P ratio
Darwin_NPRFPred<-predict(RFModelNP, newdata = Darwin)
cor.test(Darwin_NPRFPred, log(Darwin$NP))
plot(Darwin_NPRFPred, log(Darwin$NP))
sma(Darwin_NPRFPred~ log(Darwin$NP), slope.test=1)
MAE(Darwin_NPRFPred, log(Darwin$NP), na.rm = TRUE)
RMSE(Darwin_NPRFPred, log(Darwin$NP), na.rm = TRUE)

#For Cl
Darwin_ClRFPred<-predict(RFModelCl, newdata = Darwin)
cor.test(Darwin_ClRFPred, log(Darwin$Cl))
plot(Darwin_ClRFPred, log(Darwin$Cl))
sma(Darwin_ClRFPred~ log(Darwin$Cl), slope.test=1)
MAE(Darwin_ClRFPred, log(Darwin$Cl), na.rm = TRUE)
RMSE(Darwin_ClRFPred, log(Darwin$Cl), na.rm = TRUE)

#For NO3
Darwin_NO3RFPred<-predict(RFModelNO3, newdata = Darwin)
cor.test(Darwin_NO3RFPred, log(Darwin$NO3))
plot(Darwin_NO3RFPred, log(Darwin$NO3))
sma(Darwin_NO3RFPred~ log(Darwin$NO3), slope.test=1)
MAE(Darwin_NO3RFPred, log(Darwin$NO3), na.rm = TRUE)
RMSE(Darwin_NO3RFPred, log(Darwin$NO3), na.rm = TRUE)

#For Ca
Darwin_CaRFPred<-predict(RFModelCa, newdata = Darwin)
cor.test(Darwin_CaRFPred, log(Darwin$Ca))
plot(Darwin_CaRFPred, log(Darwin$Ca))
sma(Darwin_CaRFPred~ log(Darwin$Ca), slope.test=1)
MAE(Darwin_CaRFPred, log(Darwin$Ca), na.rm = TRUE)
RMSE(Darwin_CaRFPred, log(Darwin$Ca), na.rm = TRUE)

#For Mg
Darwin_MgRFPred<-predict(RFModelMg, newdata = Darwin)
cor.test(Darwin_MgRFPred, log(Darwin$Mg))
plot(Darwin_MgRFPred, log(Darwin$Mg))
sma(Darwin_MgRFPred~ log(Darwin$Mg), slope.test=1)
MAE(Darwin_MgRFPred, log(Darwin$Mg), na.rm = TRUE)
RMSE(Darwin_MgRFPred, log(Darwin$Mg), na.rm = TRUE)

#For Na
Darwin_NaRFPred<-predict(RFModelNa, newdata = Darwin)
cor.test(Darwin_NaRFPred, log(Darwin$Na))
plot(Darwin_NaRFPred, log(Darwin$Na))
sma(Darwin_NaRFPred~ log(Darwin$Na), slope.test=1)
MAE(Darwin_NaRFPred, log(Darwin$Na), na.rm = TRUE)
RMSE(Darwin_NaRFPred, log(Darwin$Na), na.rm = TRUE)

#For K
Darwin_KRFPred<-predict(RFModelK, newdata = Darwin)
cor.test(Darwin_KRFPred, log(Darwin$K))
plot(Darwin_KRFPred, log(Darwin$K))
sma(Darwin_KRFPred~ log(Darwin$K), slope.test=1)
MAE(Darwin_KRFPred, log(Darwin$K), na.rm = TRUE)
RMSE(Darwin_KRFPred, log(Darwin$K), na.rm = TRUE)

###########################################################################################################################

#Exporting Shackleton and Darwin Glacier region RF test results
Shackleton_RFtest_results<- data.frame(TaRFPred, NPRFPred, ClO4RFPred, ClRFPred, FRFPred, NO3RFPred, SO4RFPred,
                                       PO4RFPred, CaRFPred, MgRFPred, NaRFPred, KRFPred, SrRFPred, NH3RFPred)
write.csv(Shackleton_RFtest_results, file = "Shackleton_RFtest_results")


Darwin_RFtest_results <- data.frame(Darwin_TSRFPred,Darwin_NPRFPred,Darwin_ClRFPred,Darwin_NO3RFPred,
                                    Darwin_CaRFPred, Darwin_MgRFPred,Darwin_NaRFPred,Darwin_KRFPred)
write.csv(Darwin_RFtest_results, file = "Darwin_RF_test_results.csv")

###########################################################################################################################

#Quick statistical testing for linear regressions in Fig. 2

#For Total salts and Elevation, Distance from Coast, and Distance from Glacier
testTS_elev<- lm(data = Salts, log(Total_salt)~Elevation)
summary(testTS_elev)
hist(testTS_elev$resid, main="Histogram of Residuals",
     ylab="Residuals")
jarqueberaTest(testTS_elev$resid)

testTS_coast<- lm(data = Salts, log(Total_salt)~Distance_from_coast)
summary(testTS_coast)
hist(testTS_coast$resid, main="Histogram of Residuals",
     ylab="Residuals")
jarqueberaTest(testTS_coast$resid)

testTS_glac<- lm(data = Salts, log(Total_salt)~Distance_from_glacier)
summary(testTS_glac)
hist(testTS_glac$resid, main="Histogram of Residuals",
     ylab="Residuals")
jarqueberaTest(testTS_glac$resid)

#For N:P Molar Ratio and Elevation, Distance from Coast, and Distance from Glacier
testNP_elev<- lm(data = Salts, log(NP)~Elevation)
summary(testNP_elev)
hist(testNP_elev$resid, main="Histogram of Residuals",
     ylab="Residuals")
jarqueberaTest(testNP_elev$resid)

testNP_coast<- lm(data = Salts, log(NP)~Distance_from_coast)
summary(testNP_coast)
hist(testNP_coast$resid, main="Histogram of Residuals",
     ylab="Residuals")
jarqueberaTest(testNP_coast$resid)

testNP_glac<- lm(data = Salts, log(NP)~Distance_from_glacier)
summary(testNP_glac)
hist(testNP_glac$resid, main="Histogram of Residuals",
     ylab="Residuals")
jarqueberaTest(testNP_glac$resid)

#For ClO4 and Elevation, Distance from Coast, and Distance from Glacier
testClO4_elev<- lm(data = Salts, log(ClO4)~Elevation)
summary(testClO4_elev)
hist(testClO4_elev$resid, main="Histogram of Residuals",
     ylab="Residuals")
jarqueberaTest(testClO4_elev$resid)

testClO4_coast<- lm(data = Salts, log(ClO4)~Distance_from_coast)
summary(testClO4_coast)
hist(testClO4_coast$resid, main="Histogram of Residuals",
     ylab="Residuals")
jarqueberaTest(testClO4_coast$resid)

testClO4_glac<- lm(data = Salts, log(ClO4)~Distance_from_glacier)
summary(testClO4_glac)
hist(testClO4_glac$resid, main="Histogram of Residuals",
     ylab="Residuals")
jarqueberaTest(testClO4_glac$resid)

#For ClO3 and Elevation, Distance from Coast, and Distance from Glacier
testClO3_elev<- lm(data = Salts, log(ClO3)~Elevation)
summary(testClO3_elev)
hist(testClO3_elev$resid, main="Histogram of Residuals",
     ylab="Residuals")
jarqueberaTest(testClO3_elev$resid)

testClO3_coast<- lm(data = Salts, log(ClO3)~Distance_from_coast)
summary(testClO3_coast)
hist(testClO3_coast$resid, main="Histogram of Residuals",
     ylab="Residuals")
jarqueberaTest(testClO3_coast$resid)

testClO3_glac<- lm(data = Salts, log(ClO3)~Distance_from_glacier)
summary(testClO3_glac)
hist(testClO3_glac$resid, main="Histogram of Residuals",
     ylab="Residuals")
jarqueberaTest(testClO3_glac$resid)

